@@ -3,7 +3,7 @@ import logging
 import tp
 
 
-_moduleLogger = logging.getLogger('requests')
+_moduleLogger = logging.getLogger(__name__)
 
 
 class RequestsMixin(tp.ConnectionInterfaceRequests):
